@@ -115,6 +115,7 @@ class Pygments {
 		'application/x-shellscript' => 'bash',
 		'application/xslt+xml' => "xml",
 		'application/x-x509-ca-cert' => 'text',
+		'application/x-wine-extension-ini' => 'ini',
 		'message/rfc822' => 'text',
 		'text/css' => 'css',
 		'text/html' => 'xml',
@@ -190,16 +191,18 @@ class Pygments {
 			}
 
 			$extensionarray = array(
+				'automount' => 'systemd',
 				'awk' => 'awk',
-				'cast' => 'asciinema',
 				'c' => 'c',
+				'cast' => 'asciinema',
 				'coffee' => 'coffee-script',
 				'cpp' => 'cpp',
 				'cr' => 'crystal',
+				'device' => 'systemd',
 				'diff' => 'diff',
 				'go' => 'go',
-				'haml' => 'haml',
 				'h' => 'c',
+				'haml' => 'haml',
 				'hs' => 'haskell',
 				'html' => 'xml',
 				'java' => 'java',
@@ -207,12 +210,14 @@ class Pygments {
 				'json' => 'json',
 				'lhs' => 'lhs',
 				'lua' => 'lua',
+				'ml' => 'ocaml',
 				'mli' => 'ocaml',
 				'mll' => 'ocaml',
-				'ml' => 'ocaml',
 				'mly' => 'ocaml',
+				'mount' => 'systemd',
 				'mysql' => 'mysql',
 				'patch' => 'diff',
+				'path' => 'systemd',
 				'pgsql' => 'postgresql',
 				'php' => 'php',
 				'pl' => 'perl',
@@ -224,10 +229,17 @@ class Pygments {
 				'rb' => 'ruby',
 				'rs' => 'rust',
 				's' => 'asm',
+				'scope' => 'systemd',
+				'service' => 'systemd',
 				'sh' => 'bash',
+				'slice' => 'systemd',
+				'socket' => 'systemd',
 				'sql' => 'sql',
+				'swap' => 'systemd',
+				'target' => 'systemd',
 				'tcl' => 'tcl',
 				'tex' => 'tex',
+				'timer' => 'systemd',
 				'yml' => 'yaml',
 			);
 			if (array_key_exists($extension, $extensionarray)) return $extensionarray[$extension];
