@@ -6,7 +6,7 @@
  *
  * This content is released under the MIT License (MIT)
  *
- * Copyright (c) 2014 - 2019, British Columbia Institute of Technology
+ * Copyright (c) 2019 - 2022, CodeIgniter Foundation
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -30,6 +30,7 @@
  * @author	EllisLab Dev Team
  * @copyright	Copyright (c) 2008 - 2014, EllisLab, Inc. (https://ellislab.com/)
  * @copyright	Copyright (c) 2014 - 2019, British Columbia Institute of Technology (https://bcit.ca/)
+ * @copyright	Copyright (c) 2019 - 2022, CodeIgniter Foundation (https://codeigniter.com/)
  * @license	https://opensource.org/licenses/MIT	MIT License
  * @link	https://codeigniter.com
  * @since	Version 3.0.0
@@ -61,7 +62,7 @@ if ( ! function_exists('array_column'))
 	/**
 	 * array_column()
 	 *
-	 * @link	http://php.net/array_column
+	 * @link	https://secure.php.net/array_column
 	 * @param	array	$array
 	 * @param	mixed	$column_key
 	 * @param	mixed	$index_key
@@ -132,51 +133,3 @@ if ( ! function_exists('array_column'))
 		return $result;
 	}
 }
-
-// ------------------------------------------------------------------------
-
-if (is_php('5.4'))
-{
-	return;
-}
-
-// ------------------------------------------------------------------------
-
-if ( ! function_exists('hex2bin'))
-{
-	/**
-	 * hex2bin()
-	 *
-	 * @link	http://php.net/hex2bin
-	 * @param	string	$data
-	 * @return	string
-	 */
-	function hex2bin($data)
-	{
-		if (in_array($type = gettype($data), array('array', 'double', 'object', 'resource'), TRUE))
-		{
-			if ($type === 'object' && method_exists($data, '__toString'))
-			{
-				$data = (string) $data;
-			}
-			else
-			{
-				trigger_error('hex2bin() expects parameter 1 to be string, '.$type.' given', E_USER_WARNING);
-				return NULL;
-			}
-		}
-
-		if (strlen($data) % 2 !== 0)
-		{
-			trigger_error('Hexadecimal input string must have an even length', E_USER_WARNING);
-			return FALSE;
-		}
-		elseif ( ! preg_match('/^[0-9a-f]*$/i', $data))
-		{
-			trigger_error('Input string must be hexadecimal string', E_USER_WARNING);
-			return FALSE;
-		}
-
-		return pack('H*', $data);
-	}
-}
